---
title: Recipes
---

_Recipes_ are what we call the configuration file used to deploy apps with our `abra` CLI tool. A longer explanation is in the [glossary](/glossary#recipe). Our _Catalogue_ is a web interface for exploring the currently available configurations, therefore which apps can be deployed. 

### Catalogue

Our catalogue is located at [recipes.coopcloud.tech](https://recipes.coopcloud.tech/) and regularly updated :cooking:

[Browse Our Recipes](https://recipes.coopcloud.tech/){ .md-button .md-button--primary }

The catalogue is a helpful place to easily understand the status of app recipes and the link to the source-code of the recipe. To understand the various scores on recipes, read further.

## Status, Features, Score

Each recipe `README.md` has a "metadata" section, to help communicate the overall status of the recipe, and which features are supported. Here's an example, from [the Wordpress recipe](https://git.coopcloud.tech/coop-cloud/wordpress/):

```
<!-- metadata -->

* **Category**: Apps
* **Status**: 3, stable
* **Image**: [`wordpress`](https://hub.docker.com/_/wordpress), 4, upstream
* **Healthcheck**: Yes
* **Backups**: Yes
* **Email**: 3
* **Tests**: 2
* **SSO**: No

<!-- endmetadata -->
```

Currently, recipe maintainers need to update the scores in this section manually. The specific meanings of the scores are:

### Status (overall score)

| Score | Description                          |
| ----- | ------------------------------------ |
| [5](#){ .md-score .md-score-5 } | Everything in 4 + Single-Sign-On |
| [4](#){ .md-score .md-score-4 } | Upstream image, backups, email, healthcheck, integration testing |
| [3](#){ .md-score .md-score-3 } | Upstream image, missing 1-2 items from 4 |
| [2](#){ .md-score .md-score-2 } | Missing 3-4 items from 4 or no upstream image |
| [1](#){ .md-score .md-score-1 } | Alpha |

### Image

| Score | Description                          |
| ----- | ------------------------------------ |
| 4 | Official upstream image |
| 3 | Semi-official / actively-maintained image |
| 2 | 3rd-party image |
| 1 | Our own custom image |

### Email

| Score | Description                          |
| ----- | ------------------------------------ |
| 3 | Automatic (using environment variables) |
| 2 | Mostly automatic |
| 1 | Manual |
| 0 | None |
| N/A | App doesn't send email |

### CI (Continuous Integration)

| Score | Description                          |
| ----- | ------------------------------------ |
| 3 | As 2, plus healthcheck |
| 2 | Auto secrets + networks |
| 1 | Basic deployment using `stack-ssh-deploy`, manual secrets + networks |
| 0 | None |

### Single-Sign-On

| Score | Description                          |
| ----- | ------------------------------------ |
| 3 | Automatic (using environment variables) |
| 2 | Mostly automatic |
| 1 | Manual |
| 0 | None |
| N/A | App doesn't support SSO |

## Requesting Recipes

If you'd like to see a new recipe packaged there are two options for you. First is to contribte one as a _Maintainer_ 
The second option is to make a request on the [`recipes-wishlist`](https://git.coopcloud.tech/toolshed/recipes-wishlist) repository issue tracker.

If no one is around to help, you can always take a run at it yourself, go to the [Maintainers](/maintainers/) section to help you on your way.

<div class="grid cards" markdown>

- __Contribute Recipes__

    Do you not see the recipe for the app you use or make? We especially love recipe maintainers :heart:

    [Create a Recipe](/maintainers/){ .md-button .md-button--primary }

- __Request A Recipe__

    Don't feel up to the task? Open an issue in the `recipes-wishlist` repository

    [Request Recipe](https://git.coopcloud.tech/toolshed/recipes-wishlist){ .md-button .md-button--primary }

</div>

We've seen nice things happen when the requesters are also willing to take an active role in testing the new recipe. Teaming up with whoever volunteers to help do the packaging is best.
